Change Log
==========

Planned Features
----------------

The following features are intended to be included:

* Apply error models directly to ``QuantumCircuits``.
* Include simulator extensions for popular quantum software that include quantum simulators.
* Facilitate the prototyping of stabilizer ``qeccs``.

Releases
--------

PECOS 0.1.0
...........

Release date: October 3, 2018

Initial release.
